# STROOPWAFEL
Based on https://arxiv.org/abs/1905.00910

A short documentation of stroopwafel implementation can be found here -> https://docs.google.com/document/d/15To_ragEkT13gYitBoCdhq38Z97byrjGtS49Mq8cxG8

Make sure you have python3 installed in the system, if not it can be downloaded from <a href="https://www.python.org/downloads/"></a>.

This package has the following dependencies. You can run <code>pip3 install <i>package_name</i></code> for each of them.
<ul>
    <li>numpy</li>
    <li>scipy</li>
    <li>pandas</li>
</ul>

